import type {
  OrderCreateParams,
  OrderCreateResult,
  OrderListParams,
  OrderListResult,
  OrderLogisticResult,
  OrderPreResult,
  OrderResult,
} from '@/types/order'
import { http } from '@/utils/http'

/** 订单状态枚举 */
export enum OrderState {
  /** 待付款 */
  PendingPayment = 1,
  /** 待发货 */
  PendingShipment = 2,
  /** 待收货 */
  PendingDelivery = 3,
  /** 待评价 */
  PendingReview = 4,
  /** 已完成 */
  Completed = 5,
  /** 已取消 */
  Cancelled = 6,
}
/** 订单状态列表 */
export const OrderStateList = [
  { id: 0, text: '' },
  { id: 1, text: '待付款' },
  { id: 2, text: '待发货' },
  { id: 3, text: '待收货' },
  { id: 4, text: '待评价' },
  { id: 5, text: '已完成' },
  { id: 6, text: '已取消' },
]

/**
 * 获取预付订单: 从购物车跳转
 */
export const getMemberOrderPreAPI = () => {
  return http<OrderPreResult>({
    url: '/member/order/pre',
    method: 'GET',
  })
}

/**
 * 获取预付订单-立即购买: 从商品详情页跳转
 * */
type getMemberOrderPreNowParams = {
  skuId: string
  count: number
  addressId?: string
}

export const getMemberOrderPreNowAPI = (data: getMemberOrderPreNowParams) => {
  return http<OrderPreResult>({
    url: '/member/order/pre/now',
    method: 'GET',
    data,
  })
}

/**
 * 填写订单-再次购买
 * @param id 订单id
 */
export const getMemberOrderRepurchaseByIdAPI = (id: string) => {
  return http<OrderPreResult>({
    method: 'GET',
    url: `/member/order/repurchase/${id}`,
  })
}

/**
 * 提交订单
 * @param data - 订单信息
 */
export const postCreateOrderAPI = (data: OrderCreateParams) => {
  return http<OrderCreateResult>({
    url: '/member/order',
    method: 'POST',
    data,
  })
}

/**
 * 获取订单详情
 * @param id - 订单ID
 */
export const getMemberOrderDetailAPI = (id: string) => {
  return http<OrderResult>({
    url: `/member/order/${id}`,
    method: 'GET',
  })
}

/**
 * 模拟发货: 只在测试环境且待发货状态时生效
 * @param id - 订单ID
 */
export const getMockOrderConsignmentAPI = (id: string) => {
  return http({
    url: `/member/order/consignment/${id}`,
    method: 'GET',
  })
}

/**
 * 确认收货
 * @param id - 订单ID
 */
export const putMemberOrderReceiptAPI = (id: string) => {
  return http({
    url: `/member/order/${id}/receipt`,
    method: 'PUT',
  })
}

/**
 * 获取物流信息: 在待收货、待评价、已完成状态时生效
 * @param id - 订单ID
 */
export const getMemberOrderLogisticsAPI = (id: string) => {
  return http<OrderLogisticResult>({
    url: `/member/order/${id}/logistics`,
    method: 'GET',
  })
}

/**
 * 删除订单
 * @param id - 订单ID
 */
export const deleteMemberOrderAPI = (data: { ids: string[] }) => {
  return http({
    url: '/member/order',
    method: 'DELETE',
    data,
  })
}

/**
 * 取消订单
 * @param id - 订单ID
 */
export const putMemberOrderCancleAPI = (id: string, data: { cancelReason: string }) => {
  return http({
    url: `/member/order/${id}/cancel`,
    method: 'PUT',
    data,
  })
}

/**
 * 获取订单列表
 * @param data - 订单列表参数
 * @param data.page - 页码
 * @param data.pageSize - 每页条数
 * @param data.orderState - 订单状态：1待付款 2待发货 3待收货 4待评价 5已完成 6已取消
 */
export const getMemberOrderListAPI = (data: OrderListParams) => {
  return http<OrderListResult>({
    url: '/member/order',
    method: 'GET',
    data,
  })
}
